==> template-engine-0.0.1.tgz: package/lib/TemplateManager.js <==
var Class           = require("core").Class;
var JsonRpcError    = require("core").JsonRpc.JsonRpcError;
var Event           = require('core').Event.Event;
var EventDispatcher = require('core').Event.EventDispatcher;

var Template = require('./template/Template.js').Template;
/**
 * @class Responsible for managing templates. 
 * @extends EventDispatcher
 * @requires Class
 * @requires Event
 * @requires EventDispatcher
 * @requires JsonRpcError
 * @requires Template
 */
var TemplateManager = function(){
    /** @ignore */
    this.Extends = EventDispatcher;
    
    /**
     * keeps references to attached templates
     * 
     * @private
     * 
     * @type {Template[]} 
     */
    this._templates = [];
    
    /**
     * helper property, keeps count of currently rendered elements
     * 
     * @private
     * 
     * @type {integer}
     */
    this._counter = 0;
    /**
     * 
     * @private
     * 
     * @type {boolean}
     */
    this._isAborted = false;
    /**
     * keeps the error which caused the abort
     * 
     * @private
     * 
     * @type {JsonRpcError}
     */
    this._abortError = undefined;
    
    /** @ignore */
    this.initialize = function(){
        this._templates = [];
        this._counter = 0;
    };
    
    /**
     * Indicates if rendering process was aborded.
     * @public
     * @returns {boolean}
     */
    this.isAborted = function(){
        return this._isAborted;
    };

    /**
     * Return templates content object.
     * @public
     * @returns {Object} 
     */
    this.getTemplatesContent = function(){
        //TODO wywalanie niepotrzebnych elementów
        var renderedTemplates = {};
        for( var i = 0; i < this._templates.length; i++){
            var template = this._templates[i];

            if(!template.hasParent){
                if(this.isAborted()){
                    var error = JsonRpcError.factory(TemplateManager.Error.ABORTING).setData(this._abortError).toJson();
                    renderedTemplates[template.getName()] = {'error':error};
                }else{
                    if(template.getContent().isError()){
                        renderedTemplates[template.getName()] = {'error':template.getContent().getError().toJson()};
                    } else {
                        if(template.getContent().getResult()===null){
                            renderedTemplates[template.getName()] = '';
                        } else {
                            renderedTemplates[template.getName()] = template.getContent().getResult();
                        }
                        
                    }
                }
            }
        }
        
        return renderedTemplates;
    };
    /**
     * Adds a template to collection
     * @public
     * @param {Template} template
     * @throws {TemplateManager.Exception.TEMPLATE_HAS_TO_INHERIT}
     * @returns {boolean}
     */
    this.addTemplate = function(template){
        if(!template || !(template instanceof Template)){
            throw TemplateManager.Exception.TEMPLATE_HAS_TO_INHERIT;
        }

        this._templates.push(template);
        template.setTemplateManager(this);
        template.addEventListener(Template.RENDERED, this._onTemplateRendered, this);

        return true;
    };

    /**
     * Removes template from collecion
     * @public
     * @param {Template} template
     * @throws {TemplateManager.Exception.TEMPLATE_HAS_TO_INHERIT}
     * @returns {boolean}
     */
    this.removeTemplate = function(template){
        if(!template || !(template instanceof Template)){
            throw TemplateManager.Exception.TEMPLATE_HAS_TO_INHERIT;
        }

        for(var i = 0, l = this._templates.length; i < l; i++){
            if(this._templates[i] == template){
                this._templates.splice(i, 1);
                return true;
            }
        }
        
        return false;
    };
    /**
     * Returns template instance by given name
     * @public
     * @param {string} name templates name
     * @throws {TemplateManager.Exception.NAME_MUST_BE_A_STRING}
     * @returns {Template|null}
     */
    this.getTemplateByName = function(name){
        if(typeof name != "string"){
            throw TemplateManager.Exception.NAME_MUST_BE_A_STRING;
        }
        var result = null, i = 0, count = this._templates.length;

        while(i < count && name != this._templates[i].getName()){
            i++;
        }

        if(i < count){
            result =  this._templates[i];   
        }

        return result;
    };
    
    /**
     * Aborts rendering current tree. Dispatchig {@link TemplateManager.RENDERED}
     * @public
     */
    this.abort = function(error){
        //TODO zastanowic sie nad przeniesieniem logiki Abortowania flow renderingu z klasy TemplateManagera do klasy odpowiedzialnej za rendering - RenderingController. Jest to niepotrzebne mieszanie logiki renderowania i zarzadzania templateami.
        for(var i = 0, l = this._templates.length; i < l; i++){
            this._templates[i].removeEventListener(Template.RENDERED, this._onTemplateRendered);
        }

        this._isAborted = true;
        this._abortError = error;
        this.dispatchEvent(new Event(TemplateManager.RENDERED));
    };

    /**
     * Event handler called on template rendered
     *
     * @param {Event} e
     * @private
     */
    this._onTemplateRendered = function(e){
        this._counter++;
        if(this._counter == this._templates.length){
            this.dispatchEvent(new Event(TemplateManager.RENDERED));
        }
    };

    /**
     * Event handler called on template error
     * 
     * @param {ErrorEvent} e
     * @private
     */
    this._onTemplateError = function(e){
        //this._counter++;
        //this.dispatchEvent(new ErrorEvent(TemplateManager.ERROR, e));
    };
};


TemplateManager = new Class(new TemplateManager());

/**
 * Makes new template of specific type.
 * Factory method
 *
 * @static
 * @public
 * @param {string} name Template's name/file path
 * @param {object} configuration Configuration of transformation rule
 * @returns {Template}
 */
TemplateManager.createTemplate = function(name, configuration){
    var template,
        type = configuration.template.substring(configuration.template.lastIndexOf('.'), configuration.template.length);

    switch(type){
        case TemplateManager.JQTEMPLATE:
            console.log('   -- creating new JqTemplate: '+ name);
            var JqTemplate = require('./template/JqTemplate.js').JqTemplate;
            template = new JqTemplate(name, configuration);
        break;
        default:
            throw TemplateManager.Exception.UNRESOLVED_TYPE;
    }
    
    return template;
};

/**
 * @static
 * @constant
 */
TemplateManager.RENDERED = "TemplateManager_RENDERED";
/**
 * @static
 * @constant
 */
TemplateManager.ERROR = "TemplateManager_ERROR";
/**
 * @static
 * @constant
 */
TemplateManager.JQTEMPLATE = ".jqtpl";
/**
 * Namespace for exeptions messages.
 * @static
 * @constant
 * @namespace
 */
TemplateManager.Exception = {};
/**
 * @static
 * @constant
 */
TemplateManager.Exception.TEMPLATE_HAS_TO_INHERIT = 'Given template has to iherit from Template';
/**
 * @static
 * @constant
 */
TemplateManager.Exception.NAME_MUST_BE_A_STRING = 'Template name has to be a string';
/**
 * @static
 * @constant
 */
TemplateManager.Exception.UNRESOLVED_TYPE = "Error - unresolved template type.";
/**
 * Namespace for error objects.
 * @static
 * @constant
 * @namespace
 */
TemplateManager.Error = {};
/**
 * @static
 * @constant
 */
TemplateManager.Error.ABORTING = new JsonRpcError(-2101, "Aborted");

exports.TemplateManager = TemplateManager;

==> template-engine-0.0.5.tgz: package/lib/TemplateManager.js <==
var Class           = require("core").Class;
var JsonRpcError    = require("core").JsonRpc.JsonRpcError;
var Event           = require('core').Event.Event;
var EventDispatcher = require('core').Event.EventDispatcher;

// obsluga mapowania nazw templateow na pliki
var Map = {};
(function(){
    try{
        require('vm').runInNewContext(
            require('fs').readFileSync('./bin/map.js', 'utf8'), 
            Map, 
            'map.js'
        );
    } catch(e) {
        if(!Map.map){
            Map.map = function(role, kind){
                return {
                    template: kind + "/" + role + ".jqtpl",
                    className: role + " " + kind
                };
            }
        }
    }
})();



var Template = require('./template/Template.js').Template;
/**
 * @class Responsible for managing templates. 
 * @extends EventDispatcher
 * @requires Class
 * @requires Event
 * @requires EventDispatcher
 * @requires JsonRpcError
 * @requires Template
 */
var TemplateManager = function(){
    /** @ignore */
    this.Extends = EventDispatcher;
    
    /**
     * keeps references to attached templates
     * 
     * @private
     * 
     * @type {Template[]} 
     */
    this._templates = [];
    
    /**
     * helper property, keeps count of currently rendered elements
     * 
     * @private
     * 
     * @type {integer}
     */
    this._counter = 0;
    /**
     * 
     * @private
     * 
     * @type {boolean}
     */
    this._isAborted = false;
    /**
     * keeps the error which caused the abort
     * 
     * @private
     * 
     * @type {JsonRpcError}
     */
    this._abortError = undefined;
    
    /** @ignore */
    this.initialize = function(){
        this._templates = [];
        this._counter = 0;
    };
    
    /**
     * Indicates if rendering process was aborded.
     * @public
     * @returns {boolean}
     */
    this.isAborted = function(){
        return this._isAborted;
    };

    /**
     * Return templates content object.
     * @public
     * @returns {Object} 
     */
    this.getTemplatesContent = function(){
        //TODO wywalanie niepotrzebnych elementów
        var renderedTemplates = {};
        for( var i = 0; i < this._templates.length; i++){
            var template = this._templates[i];

            if(!template.hasParent){
                if(this.isAborted()){
                    var error = JsonRpcError.factory(TemplateManager.Error.ABORTING).setData(this._abortError).toJson();
                    renderedTemplates[template.getName()] = {'error':error};
                }else{
                    if(template.getContent().isError()){
                        renderedTemplates[template.getName()] = {'error':template.getContent().getError().toJson()};
                    } else {
                        if(template.getContent().getResult()===null){
                            renderedTemplates[template.getName()] = '';
                        } else {
                            renderedTemplates[template.getName()] = template.getContent().getResult();
                        }
                        
                    }
                }
            }
        }
        
        return renderedTemplates;
    };
    /**
     * Adds a template to collection
     * @public
     * @param {Template} template
     * @throws {TemplateManager.Exception.TEMPLATE_HAS_TO_INHERIT}
     * @returns {boolean}
     */
    this.addTemplate = function(template){
        if(!template || !(template instanceof Template)){
            throw TemplateManager.Exception.TEMPLATE_HAS_TO_INHERIT;
        }

        this._templates.push(template);
        template.setTemplateManager(this);
        template.addEventListener(Template.RENDERED, this._onTemplateRendered, this);

        return true;
    };

    /**
     * Removes template from collecion
     * @public
     * @param {Template} template
     * @throws {TemplateManager.Exception.TEMPLATE_HAS_TO_INHERIT}
     * @returns {boolean}
     */
    this.removeTemplate = function(template){
        if(!template || !(template instanceof Template)){
            throw TemplateManager.Exception.TEMPLATE_HAS_TO_INHERIT;
        }

        for(var i = 0, l = this._templates.length; i < l; i++){
            if(this._templates[i] == template){
                this._templates.splice(i, 1);
                return true;
            }
        }
        
        return false;
    };
    /**
     * Returns template instance by given name
     * @public
     * @param {string} name templates name
     * @throws {TemplateManager.Exception.NAME_MUST_BE_A_STRING}
     * @returns {Template|null}
     */
    this.getTemplateByName = function(name){
        if(typeof name != "string"){
            throw TemplateManager.Exception.NAME_MUST_BE_A_STRING;
        }
        var result = null, i = 0, count = this._templates.length;

        while(i < count && name != this._templates[i].getName()){
            i++;
        }

        if(i < count){
            result =  this._templates[i];   
        }

        return result;
    };
    
    /**
     * Aborts rendering current tree. Dispatchig {@link TemplateManager.RENDERED}
     * @public
     */
    this.abort = function(error){
        //TODO zastanowic sie nad przeniesieniem logiki Abortowania flow renderingu z klasy TemplateManagera do klasy odpowiedzialnej za rendering - RenderingController. Jest to niepotrzebne mieszanie logiki renderowania i zarzadzania templateami.
        for(var i = 0, l = this._templates.length; i < l; i++){
            this._templates[i].removeEventListener(Template.RENDERED, this._onTemplateRendered);
        }

        this._isAborted = true;
        this._abortError = error;
        this.dispatchEvent(new Event(TemplateManager.RENDERED));
    };

    /**
     * Event handler called on template rendered
     *
     * @param {Event} e
     * @private
     */
    this._onTemplateRendered = function(e){
        this._counter++;
        if(this._counter == this._templates.length){
            this.dispatchEvent(new Event(TemplateManager.RENDERED));
        }
    };

    /**
     * Event handler called on template error
     * 
     * @param {ErrorEvent} e
     * @private
     */
    this._onTemplateError = function(e){
        //this._counter++;
        //this.dispatchEvent(new ErrorEvent(TemplateManager.ERROR, e));
    };
};


TemplateManager = new Class(new TemplateManager());

/**
 * Makes new template of specific type.
 * Factory method
 *
 * @static
 * @public
 * @param {string} name Template's name/file path
 * @param {object} configuration Configuration of transformation rule
 * @returns {Template}
 */
TemplateManager.createTemplate = function(name, configuration, api, templatePath){
    
    var data = Map.map(configuration.role, configuration.kind);
    configuration.template = templatePath + data.template;
    configuration.params = data;
    
    var template,
        type = configuration.template.substring(configuration.template.lastIndexOf('.'), configuration.template.length);

    switch(type){
        case TemplateManager.JQTEMPLATE:
            console.log('   -- creating new JqTemplate: '+ name);
            var JqTemplate = require('./template/JqTemplate.js').JqTemplate;
            template = new JqTemplate(name, configuration, api);
        break;
        default:
            throw TemplateManager.Exception.UNRESOLVED_TYPE;
    }
    
    return template;
};

/**
 * @static
 * @constant
 */
TemplateManager.RENDERED = "TemplateManager_RENDERED";
/**
 * @static
 * @constant
 */
TemplateManager.ERROR = "TemplateManager_ERROR";
/**
 * @static
 * @constant
 */
TemplateManager.JQTEMPLATE = ".jqtpl";
/**
 * Namespace for exeptions messages.
 * @static
 * @constant
 * @namespace
 */
TemplateManager.Exception = {};
/**
 * @static
 * @constant
 */
TemplateManager.Exception.TEMPLATE_HAS_TO_INHERIT = 'Given template has to iherit from Template';
/**
 * @static
 * @constant
 */
TemplateManager.Exception.NAME_MUST_BE_A_STRING = 'Template name has to be a string';
/**
 * @static
 * @constant
 */
TemplateManager.Exception.UNRESOLVED_TYPE = "Error - unresolved template type.";
/**
 * Namespace for error objects.
 * @static
 * @constant
 * @namespace
 */
TemplateManager.Error = {};
/**
 * @static
 * @constant
 */
TemplateManager.Error.ABORTING = new JsonRpcError(-2101, "Aborted");

exports.TemplateManager = TemplateManager;
